@@ -13,9 +13,11 @@ from pkgme.info_elements import (
     Buildsystem,
     Categories,
     DebhelperAddons,
+    debian_formatted_text,
     Depends,
     Description,
     Executable,
+    ExplicitCopyright,
     ExtraFiles,
     ExtraFilesFromPaths,
     ExtraTargets,
@@ -260,8 +262,54 @@ License: BSD
 Files: debian/*
 Copyright: %(year)s The friendly pkgme.net robot
 License: public-domain
-""" % { 'year' : datetime.datetime.now().year, 
-      })
+""" % {'year' : datetime.datetime.now().year,})
+
+    def test_explicit_copyright(self):
+        package_file = self.get_object(
+            {ExplicitCopyright.name: "blah blah blah",
+             License.name: 'proprietary',
+            })
+        self.assertEqual(package_file.get_contents(),
+                         """\
+Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Upstream-Name: somepackage
+Upstream-Contact: Random Guy <foo@example.com>
+
+Files: *
+Copyright: blah blah blah
+License: proprietary
+
+Files: debian/*
+Copyright: %(year)s The friendly pkgme.net robot
+License: public-domain
+""" % {'year' : datetime.datetime.now().year,})
+
+    def test_explicit_copyright_multiline(self):
+        copyright_msg = """\
+Please see the enclosed PDF file for the exact copyright holders or contact the submitter of the application '%(submitter)s'
+
+This file was automatically generated.
+""" % {'submitter': 'Arthur Dent <arthur.dent@canonical.com'}
+        package_file = self.get_object(
+            {ExplicitCopyright.name: copyright_msg,
+             License.name: 'proprietary',
+            })
+        self.assertEqual(package_file.get_contents(),
+                         """\
+Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Upstream-Name: somepackage
+Upstream-Contact: Random Guy <foo@example.com>
+
+Files: *
+Copyright: %(clean_copyright)s
+License: proprietary
+
+Files: debian/*
+Copyright: %(year)s The friendly pkgme.net robot
+License: public-domain
+""" % {'year' : datetime.datetime.now().year,
+       'clean_copyright': debian_formatted_text(copyright_msg),
+       })
 
     def test_overwrite(self):
         package_file = self.get_object()
